@@ -52,7 +52,7 @@ class Channel(object):
             user = User(user)
         if user.nick not in self.members:
             _log.warning("Ignoring request to remove user '%s' from channel "
-                         "'%s' because that user is already in the member "
+                         "'%s' because that user is already not in the member "
                          "list.", user, self.name)
             return
         del self.members[user.nick]
@@ -401,7 +401,7 @@ class Client(object):
 
     def part(self, target, message=None):
         """Part a channel."""
-        if target not in self.server.channels:
+        if str(target) not in self.server.channels:
             _log.warning("Ignoring request to part channel '%s' because we "
                          "are not in that channel.", target)
             return
@@ -437,13 +437,15 @@ class Client(object):
 
         (Values for modes which do not take arguments are ignored.)
         """
-        if channel not in self.server.channels:
+        if str(channel) not in self.server.channels:
             _log.warning("Ignoring request to set modes in channel '%s' "
                          "because we are not in that channel.", channel)
             return
 
         chanmodes = self._get_chanmodes()
         list_modes, always_arg_modes, set_arg_modes, toggle_modes = chanmodes
+        # User privilege levels are not always included in channel modes list
+        always_arg_modes |= set(self._get_prefixes().itervalues())
 
         def _arg_to_list(arg, argument_modes, toggle_modes):
             if not isinstance(arg, dict):
@@ -682,7 +684,7 @@ def _parse_quit(client, command, actor, args):
     client.dispatch_event("QUIT", actor, message)
     for chan in client.server.channels.itervalues():
         if actor.nick in chan.members:
-            chan.remove(actor)
+            chan.remove_user(actor)
             client.dispatch_event("MEMBERS", chan)
 
 
